Coverage report

Module | statements | missing | excluded | coverage
--- | --- | --- | --- | ---
manyworlds/__init__.py | 4 | 0 | 0 | 100%
manyworlds/scenario.py | 43 | 0 | 0 | 100%
manyworlds/scenario_forest.py | 130 | 0 | 0 | 100%
manyworlds/step.py | 36 | 0 | 0 | 100%
test/__init__.py | 0 | 0 | 0 | 100%
test/test_cli.py | 18 | 0 | 0 | 100%
test/test_scenario_forest.py | 60 | 0 | 0 | 100%
Total | 291 | 0 | 0 | 100%

No items found using the specified filter.